#
# spec file for package openmw
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2012-2015 openSUSE_user1
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           openmw
Version:        0.43.0
Release:        lp150.1.3
Summary:        Reimplementation of The Elder Scrolls III: Morrowind
License:        GPL-3.0 AND MIT
Group:          Amusements/Games/RPG
Url:            http://www.openmw.org
Source:         https://github.com/OpenMW/%{name}/archive/%{name}-%{version}.tar.gz
Source2:        %{name}.rpmlintrc
BuildRequires:  MyGUI-devel >= 3.2.1
BuildRequires:  cmake
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  libboost_filesystem-devel
BuildRequires:  libboost_program_options-devel
BuildRequires:  libboost_system-devel
BuildRequires:  pkgconfig
BuildRequires:  tinyxml-devel
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5Network)
BuildRequires:  pkgconfig(Qt5OpenGL)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(bullet) >= 2.83.0
BuildRequires:  pkgconfig(libavdevice)
BuildRequires:  pkgconfig(libavformat)
BuildRequires:  pkgconfig(libavutil)
BuildRequires:  pkgconfig(libswscale)
BuildRequires:  pkgconfig(libunshield)
BuildRequires:  pkgconfig(openal)
BuildRequires:  pkgconfig(openscenegraph) >= 3.2
BuildRequires:  pkgconfig(openthreads) >= 3.2
BuildRequires:  pkgconfig(sdl2)
Requires:       OpenSceneGraph-plugins
Requires(post): desktop-file-utils
Requires(postun): desktop-file-utils

%description
OpenMW is a new and modern engine based on the one that runs the 2002 open-world RPG Morrowind. The engine (OpenMW) will come with its own editor (OpenCS) which will allow the user to edit or create their own games. Both OpenCS and OpenMW are written from scratch and aren’t made to support any third party programs the original Morrowind engine uses to improve its functionality.
To give you a better idea of what this project is about, here are some of the aims for the future of the OpenMW engine:

  * Be a full-featured reimplementation of the Morrowind engine.
  * Run natively on Windows, Linux and MacOS X.
  * Support all existing content, including Tribunal, Bloodmoon and all user created mods (in case they don’t
     use external programs).
  * Allow much greater modability: change game rules, create new spell effects, etc. through scripting.
  * Fix system design bugs, like save-game “doubling” problem.
  * Improve the interface and journal system.
  * Improved graphics by taking advantage of more modern hardware.
  * Support to improve game mechanics, physics, combat and AI.
  * (Possibly) Support to implement multiplayer
  * (Possibly) Support to run on mobile devices.

NOTE(!!!): Playing Morrowind with this engine STILL REQUIRES one to own the Morrowind data files.

OpenCS will support the editing of all OpenMW features. We aim for the editor to stay fully up-to-date with the corresponding OpenMW version, allowing the user to edit any newly implemented features. Post v1.0 features are going to be the use of OpenCS as a debugging tool for OpenMW content and the support for editor plugins.
These are files that add to the editor code, improving its functionality to allow it to have some nice extras.
The OpenCS is not based on the editing tool which came with the original Morrowind game, it is a program made by modders for modders. Important properties of the OpenCS are:

 * non-blocking
 * multi-threaded
 * multi-document support
 * multi-view support
 * high scalability
 * customisable GUI

%prep
%setup -q -n %{name}-%{name}-%{version}

## fix __DATE__ and __TIME__
STATIC_BUILDTIME=$(LC_ALL=C date -u -r %{_sourcedir}/%{name}.changes '+%%H:%%M')
STATIC_BUILDDATE=$(LC_ALL=C date -u -r %{_sourcedir}/%{name}.changes '+%%b %%e %%Y')

%define _sed_work sed -i -e 's/__DATE__/"$STATIC_BUILDDATE"/' -e 's/__TIME__/"$STATIC_BUILDTIME"/'
%{_sed_work} apps/launcher/maindialog.cpp
# Fix line endings
for file in tables.tex main.tex recordtypes.tex filters.tex creating_file.tex files_and_directories.tex windows.tex; do
	sed -i "s/\r$//" "manual/opencs/$file"
done

%build
%cmake -DGLOBAL_DATA_PATH="%{_datadir}/" \
       -DMORROWIND_DATA_FILES="%{_datadir}/%{name}/data/" \
       -DOPENMW_RESOURCE_FILES="%{_datadir}/%{name}/resources/" \
       -DUSE_SYSTEM_TINYXML="ON" \
       -DDESIRED_QT_VERSION=5 \

make %{?_smp_mflags} VERBOSE=1

%install
%cmake_install

## set the default data location
sed -i -e 's#data="?global?.*$#data="%{_datadir}/%{name}/data"#' \
 %{buildroot}%{_sysconfdir}/%{name}/%{name}.cfg || exit 1

## Install data
cp -pr files/launcher %{buildroot}%{_datadir}/%{name}/resources/ || exit 1

## Install docs
install -d -m755 %{buildroot}%{_docdir}/%{name}/licenses
cp -pr %{buildroot}%{_datadir}/licenses/%{name}/* %{buildroot}%{_docdir}/%{name}/licenses/ || exit 1
rm -rf %{buildroot}%{_datadir}/licenses/
install -m644 README.md CHANGELOG.md AUTHORS.md  %{buildroot}%{_docdir}/%{name}/
install -m644 docs/license/GPL3.txt %{buildroot}%{_docdir}/%{name}/licenses/
rm -f manual/opencs/.gitignore
cp -r manual/opencs %{buildroot}%{_docdir}/%{name}/ || exit 1

## fix location of appdata 
mkdir -p %{buildroot}/%{_datadir}/appdata
mv %{buildroot}/%{_datadir}/metainfo/* %{buildroot}/%{_datadir}/appdata/
rm -Rf %{buildroot}/%{_datadir}/metainfo

%suse_update_desktop_file %{name}
%suse_update_desktop_file %{name}-cs
%fdupes %{buildroot}%{_datadir}

%post
/sbin/ldconfig
%desktop_database_post

%postun
/sbin/ldconfig
%desktop_database_postun

%files
%dir %{_datadir}/%{name}
%dir %{_sysconfdir}/%{name}
%dir %{_docdir}/%{name}
%{_docdir}/%{name}/*
%{_datadir}/%{name}/*
%{_datadir}/pixmaps/*.png
%{_datadir}/applications/*.desktop
%dir %{_datadir}/appdata
%{_datadir}/appdata/openmw.appdata.xml
%config(noreplace) %{_sysconfdir}/%{name}/openmw.cfg
%config(noreplace) %{_sysconfdir}/%{name}/openmw-cs.cfg
%config(noreplace) %{_sysconfdir}/%{name}/settings-default.cfg
%config(noreplace) %{_sysconfdir}/%{name}/gamecontrollerdb.txt
%config %{_sysconfdir}/%{name}/version
%{_bindir}/bsatool
%{_bindir}/esmtool
%{_bindir}/%{name}
%{_bindir}/%{name}-essimporter
%{_bindir}/%{name}-iniimporter
%{_bindir}/%{name}-cs
%{_bindir}/%{name}-launcher
%{_bindir}/%{name}-wizard

%changelog
* Sat Dec  9 2017 mimi.vx@gmail.com
- fix boost BuildRequires
* Mon Dec  4 2017 mimi.vx@gmail.com
- update to new release 0.43.0 - see CHANGELOG.md for details
* Wed Aug  2 2017 mimi.vx@gmail.com
- Update to new release 0.42.0 see CHANGELOG.md for more details
* Fri Dec 23 2016 mimi.vx@gmail.com
- Update to new release 0.41.0 see CHANGELOG.md for more details
* Mon Nov 28 2016 mimi.vx@gmail.com
- Force use of Qt5
* Sat Sep 10 2016 mimi.vx@gmail.com
- add OpenSceneGraph-plugins to requires -- fixes dds texture loading
* Fri Sep  9 2016 mimi.vx@gmail.com
- Update new release 0.40.0, for changelog see CHANGELOG.md
- dropped fix-unordered-map.patch
- moved to Qt5
- use system tinyxml
- spec-cleaned with spec-cleaner
- correctly handle desktop file
* Sun Jul 10 2016 rpm@fthiessen.de
- Added fix-unordered-map.patch to fix build with gcc >= 6.0
* Wed May  4 2016 rpm@fthiessen.de
- Update to new release 0.39.0, for change log see CHANGELOG.md or
    https://github.com/OpenMW/openmw/blob/master/CHANGELOG.md
* Tue Jan 26 2016 rpm@fthiessen.de
- Update to upstream version 0.38.0:
  * Fixed player object being deletable
  * Fixed AiCombat distance check to take into account collision box
  * Fixed saw in Dome of Kasia not hurting a stationary player
  * Fixed rats floating when killed near a door
  * Fixed kwama eggsacks pulsing too fast
  * Fixed NPC voice sound source not being placed at their head
  * Fixed crash with OpenMW install wizard
  * Fixed reseting delete flag when loading a reference from a save game
  * Fixed issues with clicking on unexpected inventory items on character doll
  * Fixed spell absorption to apply once per effect
  * Fixed enchantment merchant items reshuffling every time barter is clicked
  * Fixed not being able to resurrect the player through the console if health is zero
  * Fixed projectile weapon behavior when underwater
  * Fixed not being able to use keywords in strings for message boxes
  * Fixed items not sinking when dropped underwater
  * Fixed crash when onPcEquip script removes the equipped item
  * Fixed dialog not triggering correctly in Julan Ashlander Companion mod
  * Fixed tooltips for Health, Magicka, and Fatigue showing in the Options menu when bars aren't visible
  * Fixed guards accepting gold for crimes even when you don't have enough
  * Fixed Show Owned option affecting tooltips that are not objects
  * Fixed player sound source being at the feet
  * Fixed not being able to replace interactive message boxes
  * Fixed fatal error on OpGetTarget when the target has disappeared
  * Fixed first person rendering glitches with high field of view
  * Fixed crash on new game at character class selection
  * Fixed RigGeometry bone references to be case-insensitive
  * Fixed NPCs using wrong sound when landing
  * Fixed missing journal textures without Tribunal and Bloodmoon installed
  * Fixed multiple AiFollow packages causing the distance to stack
  * Fixed creature dialogs not being handled correctly
  * Fixed crash when entering Holamayan Monastery with mesh replacer installed
  * Fixed dreamers spawning too soon
  * Fixed Next/Previous Weapon/Spell and Ready Spell working as a werewolf
  * Fixed being able to soultrap a creature more than once
  * Fixed summoned creatures and objects disappearing at midnight
  * Fixed gamecontrollerdb file being created as a txt instead of a cfg
  * Fixed "same race" dialog functions never triggering
  * Fixed dialog choice condition issue
  * Fixed body part rendering when in a pose
  * Fixed reversed sneak awareness check
  * Fixed positional sound acceleration issue
  * Fixed fatal error when LandTexture is missing
  * For all changes see also CHANGELOG.md or
    https://github.com/OpenMW/openmw/blob/master/CHANGELOG.md
* Tue Jun  9 2015 devel.suse@gmail.com
- Update to upstream version 0.36.1:
  * Fixed additional startup scripts failing to launch
  Known Issues:
  * Crash when trying to view cell in render view in OpenMW-CS on OSX
  * Crash when switching from full screen to windowed mode on D3D9
* Sat May 23 2015 devel.suse@gmail.com
- Change libffmpeg-devel to ffmpeg-devel in .spec file due to
  new dependency package name
* Mon Mar 16 2015 devel.suse@gmail.com
- Update to upstream version 0.35.1:
  * Implemented being able to dress corpses (you weirdos)
  * Implemented checking Cmake sets correct MSVC compiler settings for release build
  * Implemented default values for mandatory global records
  * Implemented basic joystick support
  * Implemented a progress bar for Morrowind.ini import progress in the launcher
  * Implemented passage of time indicator when training or serving jail time
  * Fixed a crash caused by a land record without data
  * Fixed creatures with no skeleton base causing a crash
  * Fixed engine becoming unresponsive when trying to use equip next/previous with an empty inventory
  * Fixed error caused by relying on subrecord order when reading content files
  * Fixed sun trajectory
  * Fixed stolen items handling to match vanilla Morrowind
  * Fixed Divine Intervention sending the player to the wrong place in some cases
  * Fixed telekinesis not working to avoid traps
  * Fixed combat AI for unreachable enemies
  * Fixed object scale being considered in the Move instruction
  * Fixed multi-effect spells with different ranges not all applying
  * Fixed launcher not responding to Ctrl+C command from the terminal
  * Fixed drag-and-drop creating duplicate content files in the launcher when Alt is pressed
  * Fixed addon files with no dependencies not showing in the launcher
  * Fixed Detect Animal detecting dead creatures
  * Fixed Cmake not respecting LIB_SUFFIX
  * Fixed changing active magic holstering magic hands
  * Fixed switching spells with next or previous while holding shift raising the delete spell dialog
  * Fixed regression causing ignored clicks on the HUD mini-map
  * Fixed instant restore effect behavior
  * Fixed CE restore attribute items permanently boosting the stat they restore
  * Fixed being able to fall off the prison ship
  * Fixed wrong starting position in "Character Stuff Wonderland"
  * Fixed plugin load order being sorted incorrectly when importing Morrowind settings
  * OpenMW-CS: Fixed skills saving incorrectly
  * OpenMW-CS: Fixed file extension inconsistency
  Known Issues:
  * Crash when trying to view cell in render view in OpenMW-CS on OSX
  * Crash when switching from full screen to windowed mode on D3D9
- Drop openmw-lib-suffix.patch (fixed upstream)
* Sat Mar  7 2015 devel.suse@gmail.com
- Change datadir to /usr/share/openmw
* Tue Feb 17 2015 devel.suse@gmail.com
- Add /sbin/ldconfig call to .spec
* Tue Feb 17 2015 devel.suse@gmail.com
- Add openmw-lib-suffix.patch
* Tue Feb 17 2015 devel.suse@gmail.com
- Update to upstream version 0.35.0:
  * Implemented Calm effect removing combat packages
  * Implemented first stages of ess-Importer, an importer for vanilla Morrowind save games, this feature is not complete
  * Implemented previous/next weapon and spell equipping hotkeys
  * Implemented XYZ rotation keys support
  * Implemented AI fast-forward
  * Implemented NPC drowning while knocked out
  * Implemented setting for exterior cell grid size
  * Implemented some leveled list script functions
  * Implemented testing dialog scripts with --script-all
  * Implemented NPC lookAt controller
  * Implemented handling initial state of particle system
  * Implemented a warning when loading a savegame that depends on non-existent content files
  * Implemented conversion of global map exploration overlay for ess-Importer
  * Implemented command line option to load a save game
  * Implemented new display of load order problems in the Data Files tab of the launcher
  * Fixed some sound effects playing at very loud levels
  * Fixed transparency issues with some UI elements
  * Fixed launcher handling of master and plugin selections loaded from openmw.cfg
  * Fixed water display issue on AMD cards
  * Fixed a text display issue when highlighting words in dialog
  * Fixed a launcher crash when a content file is locked
  * Fixed being able to stand on top of hostile creatures
  * Fixed creatures climbing on top of the player
  * Fixed AITravel to more accurately emulate vanilla
  * Fixed some moon display issues
  * Fixed place-able items having collision
  * Fixed AIFollow distance for groups of multiple followers
  * Fixed some staircase climbing issues in Vivec
  * Fixed permanent magic effects not being saved in savegames
  * Fixed crash due to zero-sized particles
  * Fixed a model scaling issue
  * Fixed activated enchanted item magic not being saved in savegames
  * Fixed a crash caused by Ogre shadow handling
  * Fixed not being able to equip a shield with a two-handed weapon
  * Fixed an issue with player fall height when stepping down
  * Fixed an error-handling issue preventing the Sword of Perithia mod from loading
  * Fixed launcher reseting alterations made to the mod list order
  * Fixed some issues with NPC idle voices
  * Fixed vampire corpses standing up when being looted
  * Fixed spell cost not highlighting on mouseover
  * Fixed tooltips still showing when menu is toggled off
  * Fixed rain effect showing while underwater
  * Fixed extreme framedrop when running into certain corners
  * Fixed mod "Shrines - Restore Health and Cancel Options" restore health option not working
  * Fixed animation groups for light and door objects
  * Fixed slaughterfish not attacking partially submerged enemies
  * Fixed air movement mechanics
  * Fixed handling of NPCs with missing hair/head models
  * Fixed position flicker after an animation ends
  * Fixed supporting region names in cell dialog filter for mod "Julan Ashlander Companion"
  * Fixed issues with animated collision shape
  * Fixed mod "Morrowind Rebirth 2.81" causing Balmora bridges to not have collision
  * Fixed summons to reset when the spell is recast
  * Fixed equipment update when unequipping non-related items removing ammunition
  * Fixed not falling back to the top-level directory when looking for resources
  * Fixed mod pathgrids not overwriting the existing pathgrid
  * Fixed a gameplay stopper with the Russian version of the ChaosHeart mod
  * Fixed the resurrect function to work correctly
  * Fixed functionality to allow mods to overwrite existing records in the IndexedStore
  * Fixed an issue with extra bytes to fix an error with the mod "Animated Morrowind - Expanded"
  * Fixed multi-character comparison operators to allow spaces
  * Fixed handling deleted references to fix the "Gateway Ghost" quest
  * Fixed summoning to allow multiple instances of the same creature by using different spells
  * Fixed pathgrid in the (0, 0) exterior cell not loading
  * Fixed actor original position not being saved with the wander package
  * Fixed creatures not receiving fall damage (shouts to this amazing bug description: http://bugs.openmw.org/issues/2201 )
  * Fixed enchant cost issue
  * Fixed handling of missing spells and factions to be more graceful
  * Fixed several book display issues
  * Fixed some script compilation issues
  * Fixed scale field for creatures not being handled
  * Fixed being able to use enchantments from items that failed to equip
  * Fixed handling names for helmet models
  * Fixed some NPCs not attacking when they are pickpocketed
  * Fixed chargen race preview head default orientation
  * Fixed animations with no loop keys being looped
  * Fixed spell making to allow adding multiple attribute/skill effects
  * Fixed crash when northmarker has been disabled
  * Fixed area effect on touch spell behavior
  * Fixed dwarven crossbow clipping through the ground when dropped
  * Fixed torch animation playing when torch is hidden
  * Fixed sneak re-applying after attacking an NPC
  * Fixed handling for bipedal creatures without weapons
  * Fixed conflict resolution for conflicting dialog topics
  * Fixed tab completion for exterior cell names
  * Fixed third person view being preserved in save games
  * Fixed save/load progress bar behavior
  * Fixed TogglePOV not being bindable to the Alt key
  * Fixed exception for empty dialog topics
  * Fixed PlaceAt function's count behavior
  * Fixed map notes to display on the door marker leading to the cell with that note
  * Fixed some UI issues to be better compatible with UI overhaul mods
  * Fixed an issue with leveled item arguments
  * Fixed enchanted arrows being added to the victim
  * Fixed missing sound for drawing throwing weapons
  * Fixed guards detecting invisible players
  * Fixed camera not being attached properly when player becomes a vampire
  * Fixed visual effects showing on the overhead map
  * Fixed health modifier not resetting when an actor dies
  * Fixed God Mode to not require magicka when casting spells
  * Fixed attachArrow exception when changing weapon
  * Fixed error when disabled objects are moved between cells
  * Fixed scripts with names starting with digits failing to compile
  * Fixed click activate and de-activate behavior in the Data Files list
  * Renamed "profile" to "content list" in the launcher
  * Added comments to the local/global openmw.cfg files to clarify their identity
  * OpenMW-CS: Implemented clicking on a script error in the report window to set the cursor in the script editor to the
  respective line/column
  * OpenMW-CS: Implemented deleting selected rows from result windows
  * OpenMW-CS: Fixed window opening issue when the config file doesn't exist
  * OpenMW-CS: Fixed skills to allow values other than 0 through 99
  * OpenMW-CS: Fixed an issue with not launching when another instance was falsely detected as running
  * OpenMW-CS: Fixed a crash on launch when OpenMW is not installed as well
  * OpenMW-CS: Cleanup for the Opening Window and User Settings Window
  Known Issues:
  * Crash when trying to view cell in render view in OpenCS on OSX
  * Crash when switching from full screen to windowed mode on D3D9
* Wed Jan 21 2015 devel.suse@gmail.com
- Update to upstream version 0.34.0:
  * Implemented ClampMode in NiTexturingProperty, fixes some floating plant textures
  * Implemented INI-importer for the launcher
  * Implemented "encoding" option in the launcher
  * Disabled third-person zoom by default due to usability issues (can be re-enabled in settings file)
  * Fixed several launcher and installation issues
  * Fixed issue with BIK video/audio playback sync
  * Fixed NPCs ignoring player invisibility when engaged in combat
  * Fixed long class names being cut off in the UI
  * Fixed running while levitating draining fatigue
  * Fixed handling of disabled plugins
  * Fixed ToggleMenus not closing dialog windows
  * Fixed crash when calling getDistance on items in the player's inventory
  * Fixed the Buglamp tooltip showing the item weight
  * Fixed slave crime reaction to PC picking up slave's bracers
  * Fixed Dremora death animation
  * Fixed Mansilamat Vabdas's floating corpse
  * Fixed bounty not being completely removed after the Larius Varro Tells A Little Story quest
  * Fixed silenced enemies attempting to cast spells
  * Fixed The Warlords quest
  * Fixed sneak attacks on hostiles causing a bounty
  * Fixed a crash caused by incorrect handling of getPcRank and similar defines
  * Fixed pause in Storm Atronach animation
  * Fixed a bug in TerrainGrid::getWorldBoundingBox
  * Fixed crash on exceptions while adding startup scripts
  * Fixed AiWander path finder hang when quickly changing cells
  * Fixed crash when playing OGG files
  * Fixed Dagoth Gares talking to the player even when he is not there
  * Fixed overflow exploit in bartering
  * Fixed a crash when maximizing the window with the race selection dialog open on D3D9
  * Fixed script command "Activate, player" not working
  * Fixed buttons only lighting on hover over their label
  * Fixed Slowfall effect being too weak
  * Fixed several skeleton/bone model and animation issues
  * Fixed script handling to treat the [ character as whitespace
  * Fixed a crash in character preview for non-existing meshes
  * Fixed abrupt transition when ash storms end
  * Fixed mouse movements being tracked during video playback
  * Fixed a crash on exit
  * Fixed being able to attack Almalexia during her final monologue
  * Fixed the frame time cap not being applied to Ogre's ControllerManager
  * Fixed recalculation of Magicka to be less aggressive
  * Fixed Azura's spirit fading away too fast
  * Fixed Magicka becoming negative
  * Fixed health so it drops to 0 if it goes below 1.
  * Fixed floating hairs in Westly's Pluginless Head And Hair Replacer
  * Fixed some issues with mods that use conversation scripts to update the PC
  * Fixed graphical issues with Morrowind Grass Mod
  * Fixed issues with renaming profiles in the launcher
  * OpenCS: Implemented rendering cell markers
  * OpenCS: Implemented double-click functionality in tables
  * OpenCS: Implemented user settings dialog grouping, labeling, and tooltips
  * OpenCS: Implemented editing positions of references in the 3D scene
  * OpenCS: Implemented edit mode button on the scene toolbar
  * OpenCS: Implemented user setting for showing the status bar
  * OpenCS: Improved the layout of the user settings dialog
  * OpenCS: Fixed script compiler sometimes failing to find IDs
  * OpenCS: Fixed verifier not handling Windows-specific path issues when dealing with resources
  * OpenCS: Fixed display of combat/magic/stealth values
  * OpenCS: Fixed saving
  * OpenCS: Fixed exception caused by following the Creature column of a SoundGen record
  * OpenCS: Fixed MDL subrecord error
  * OpenCS: Fixed coordinate and rotation editing
  * OpenCS: Fixed several window and view handling issues
  * OpenCS: Fixed loading plugins with moved references, implementation of moved references still pending
  * OpenCS: Fixed a crash when closing cell render window on OSX
  Known Issues:
  * Crash when trying to view cell in render view in OpenCS on OSX
  * Crash when switching from full screen to windowed mode on D3D11
- Drop openmw-cmake-OGRE-lib-path.patch
- Drop openmw-opencs-fix-saving.patch
* Mon Jul 28 2014 devel.suse@gmail.com
- add openmw-opencs-fix-saving.patch and removed workaround
* Mon Jul 28 2014 devel.suse@gmail.com
- fix OpenCS saving ability
* Thu Jul 17 2014 devel.suse@gmail.com
- Update to upstream version 0.31.0:
  * Implemented periodic cleanup/refill
  * Implemented precipitation and weather particles
  * Implemented dialogue merging
  * Implemented saving missing creature state
  * Implemented saving fog of war state
  * Implemented NPCs and creatures fighting each other
  * Implemented murder crime
  * Implemented Sneak skill enhancements
  * Implemented item restock handling
  * Implemented save game levelled creature handling
  * Implemented modFactionReaction script instruction
  * Implemented animated main menu support
  * Implemented saving walk/run toggle state
  * Implemented save game naming changes
  * Implemented a delete button on the load game menu
  * Implemented using journal while in dialog
  * Implemented battle music while in combat
  * Implemented follower fast travel
  * Implemented disposition and distance based aggression
  * Fixed clouds and weather to better match vanilla Morrowind
  * Fixed local map not showing objects that span multiple cells
  * Fixed CenterOnCell behavior to better match vanilla Morrowind
  * Fixed local and world map display issues
  * Fixed water being luminescent at night
  * Fixed launcher not supporting non-latin paths on Windows
  * Fixed background tracks repeating
  * Fixed door animation behavior when leaving a cell
  * Fixed disabled stronghold statics showing on the world map
  * Fixed excessive vram usage after extended play
  * Fixed dead body collision behavior
  * Fixed several character creation issues
  * Fixed various issues with jumping
  * Fixed delay on reflection effects
  * Fixed being able to interact with the world during Wait/Rest dialog
  * Fixed being able to drop items inside walls and ceilings
  * Fixed corpses changing orientation when re-entering a cell
  * Fixed several footstep sound issues
  * Fixed several dialog link issues
  * Fixed broken dialog topics in Russian version
  * Fixed summoned creature duration issue
  * Fixed crimes against hostile NPCs issue
  * Fixed creature run speed formula
  * Fixed weakness to fire not working with fire damage in the same spell
  * Fixed NPCs killing each other while attacking the player
  * Fixed Bittercup script not working on 'Take' option
  * Fixed case sensitivity for .bsa files
  * Fixed crash when loading a save after being killed
  * Fixed jumping not being disabled when showing message boxes
  * Fixed binding keys to uncommon characters
  * Fixed container selection changing based on mouse pointer position
  * Fixed a load/save issue with dynamic records
  * Fixed double paste into console
  * Fixed crash with D3D9 shaders
  * Fixed incorrect slope climb allowing the player to skip chargen
  * Fixed slaughterfish detecting player when player is out of the water
  * Fixed error when loading Animated Morrowind
  * Fixed NPC footsteps persisting after killing a moving NPC
  * Fixed previously equipped items not shown as unequipped after attemping to sell them
  * Fixed actors ignoring vertical axis when deciding to attack
  * Fixed blank toggle option for shadows in options menu
  * Fixed Ashlands being visible during new game loading process
  * Fixed guards prompting with punishment options after player resists arrest with another guard
  * Fixed a gate activation in TR
  * Fixed dependent files not getting disabled in launcher when parent is disabled
  * Fixed several code fragments
  * Fixed incorrect voice type playing on sleep interrupt
  * Fixed save games not showing in menu in certain cases
  * Fixed lights without a model not working
  * Fixed Animation Compilation mod not working properly
  * Fixed third party SL_Pick01.nif not working
  * Fixed being unable to exit dialog after stealing in front of Sellus Gravius
  * Fixed installs to /usr/local not working
  * Fixed failure to load save if one of the content files is disabled
  * Fixed crash on loading Siege at Firemoth
  * Fixed Arkngthand door not opening
  * Fixed Segfault when modifying view distance in options
  * Fixed apostrophe and dash characters not displaying in French version
  * Fixed display issue with icon background for magic items
  * Fixed display issue with coin icon on level up dialog
  * Fixed Alt+F4 not working in Windows
  * Fixed changing ring behavior
  * Fixed robes hiding pauldrons
  * Fixed button orientation on some shrine dialogs
  * Fixed items floating in the air when dropped onto corpses
  * Fixed forearms not rendering on Argonian females
  * Fixed alchemy allowing making potions from two of the same item
  * Fixed Max Sale button behavior
  * Fixed rest until healed for characters with stunted magicka
  * Fixed empty travel window displaying during new game sequence
  * Fixed save game permission issue
  * Fixed crash when loading The Underground 2 mod
  * Fixed ignoring additional splash screens
  * Fixed perpetual save load issue
  * Fixed error with Skyrim: Home of the Nords
  * Fixed many script instruction behaviors
  * Fixed read skill books not being saved in save game
  * Fixed unusable items being able to get bound to hotkeys
  * Fixed text variables in journal topic list
  * Fixed repeating swings on friendly NPC counting as additional crimes
  * Fixed lack of punishment for stealing priceless items
  * Fixed door marker at Jobasha's Rare Books spawning PC in the air
  * Fixed topic selection menu to be wider
  * Fixed items dropped on rug being inaccessible
  * Fixed crime for dropping and taking looted items
  * Fixed location of dropped arrows and bolts
  * Fixed security trainers offering acrobatics instead
  * Fixed punishment dialog displaying instead of load when killed by a guard
  * Fixed script error in SkipTutorial
  * Fixed bad lighting when using morrowind.ini generated by MGE
  * Fixed mobile Heart of Lorkan
  * Fixed keybindings not saving
  * Fixed apathetic Dura Gra-Bol
  * Fixed Morrowind Patch preventing interior cell load
  * Fixed item value on tooltip
  * Fixed death count not storing in savegame
  * Fixed submerged portion of weapon not rendering when partially submerged
  * Fixed enemies attacking while dying
  * Fixed ESM error with INFO
  * Fixed projectiles shot at player ending up in inventory
  * Fixed monsters respawning on top of each other
  * Fixed dialog box opening on follower NPC when NPC is dead or game is paused
  * Fixed floating paralyzed cliffracers
  * Fixed message boxes not clearing when loading a different save game
  * Fixed underwater sound sometimes playing when transitioning from an interior
  * Fixed spell projectiles not colliding with water surface
  * Fixed console error message when information is refused by an NPC
  * Fixed being unable to remove arrow during Bloodmoon: The Ritual of Beasts quest
  * Fixed being unable to talk to Carnius Magius in Bloodmoon
  * Fixed crash when attempting to play a non-music file
  * Fixed world map not being centered on player in certain cases
  * Fixed arrow behavior in wait/rest dialog
  * Fixed kills not filling werewolf hunger
  * Fixed detect life behavior while a werewolf
  * Fixed crash during The Shrine of the Dead mission in Tribunal
  * Fixed selected text background color in the console
  * Fixed handling extra arguments given to script instructions
  * Fixed NPCs taunting after they are dead in An Assassionation Attempt quest
  * Fixed game halt when attacked by Centurion Archers
  * Fixed quest journal when completing The Missing Hand quest
  * Fixed several issues with the Dome of Serlyn
  * Fixed bounty being calculated from actual item value instead of highest value
  * Fixed terrain turning invisible on top of Red Mountain
  * Fixed steam appearance in Cave of the Hidden Music quest
  * Fixed display issues when picking up a stack of items, holding enter, and moving the mouse
  * Fixed Draugr and Riekling attacks
  * Fixed Bonewolf animation
  * Fixed particle effects being paralyzed when the player is paralyzed
  * Fixed Crimson Plague quest not updating when Gedna Relvel is killed
  * Fixed failed save game when saving in Old Mournhold: Forgotten Sewer
  * Fixed segfault when making Drain/Fortify Skill spells
  * Fixed case where game wouldn't switch to fullscreen
  * Fixed Morrowind Rebirth duplicate objects/vanilla objects not being removed
  * Fixed case where paralysis and switching view modes would prevent death notification
  * Fixed an alt+tab segfault
  * Various code maintenace and cleanup
  * OpenCS: Implemented object rendering in cells
  * OpenCS: Implemented configuration setup
  * OpenCS: Implemented threaded loading
  * OpenCS: Implemented cell record saving
  * OpenCS: Implemented body part table
  * OpenCS: Implemented enchantment effect table
  * OpenCS: Implemented deleting referenceables
  * OpenCS: Fixed Combat/Magic/Stealth values for creatures are not displayed
  * OpenCS: Fixed segfault after 'new' or 'load'
  * OpenCS: Fixed deleting Record Filter line not reseting the filter
  * OpenCS: Fixed crash when drag and dropping text
  * OpenCS: Fixed bogus filter being created when dragging multiple records to the filter bar of a non-applicable table
  Known Issues:
  * Switching from fullscreen to windowed mode on Windows 7 or 8.1 while using the D3D9 renderer causes a crash
  Was this fixed?
  * Bug #1567: Editor: Deleting of referenceables does not work
- Known issue: OpenCS saving project doesn't work
* Wed Jul 16 2014 devel.suse@gmail.com
- Add docs and opencs content editor to spec
* Wed Jun 18 2014 devel.suse@gmail.com
- Update to upstream version 0.30.0:
  * Implemented Ranged Combat
  * Implemented Sneaking Skill icon
  * Implemented Crime and Punishment
  * Implemented correct trader gold handling
  * Implemented AIFollow package on summoned creatures
  * Implemented run stance in the AIFollow package
  * Implemented all NPCs in the area attacking the player when the player attacks one
  * Implemented terrain threading
  * Implemented correct GUI save/load progress bars
  * Implemented saving the weather state in save games
  * Implemented class creation form remembering previous changes
  * Implemented quicksave, quickload, and autosave
  * Implemented deleting saves
  * Implemented bribe gold being placed into the NPCs inventory
  * Implemented saving quick key bindings
  * Implemented NPCs returning to their default position after pursuing the player for a crime
  * Implemented vertical axis navigation for flying and swimming creatures
  * Implemented functionality for NPCs to evade each other when walking around
  * Fixed extreme shaking that could occur during cell transitions while moving
  * Fixed crash when a non-existent content file is added to openmw.cfg
  * Fixed OpenMW allowing resting/using a bed while in combat
  * Fixed crime punishment in the Census and Excise Office at the start of a new game
  * Fixed evidence chests not re-locking after new evidence is put in them
  * Fixed NPCs still attacking after punishment is served
  * Fixed taking items from a corpse being considered a crime
  * Fixed some creatures not being able to get close enough to attack
  * Fixed dead creatures dying again each time the player enters the cell
  * Fixed input manager state not being handled correctly when loading a save
  * Fixed crash when trying to get LOS of disabled NPC
  * Fixed incorrect inventory behavior before inventory is activated in a new game
  * Fixed NPCs not equipping torches in dark interiors
  * Fixed mouse wheel scrolling too fast in race selection
  * Fixed doors being blocked by NPCs
  * Fixed repair/charge indicators not updating
  * Fixed scribs not defending themselves
  * Fixed creatures life bar not always being empty when they are dead
  * Fixed creature and hand to hand attacks not increasing armor skill
  * Fixed undead and mechanical creatures bleeding red blood
  * Fixed Tarhiel never falling
  * Fixed script variables not being saved
  * Fixed custom class names not being handled properly in save games
  * Fixed NPCs stuttering when walking indoors
  * Fixed menu appearing when trying to skip intro movie
  * Fixed NPCs getting stuck when they run into each other
  * Fixed health bar showing permanently when running BTB-Settings
  * Fixed guard killing PC when Khajiit race is selected when running BTB-Character
  * Fixed HUD weapon icon showing a fist after loading a save, when a weapon is equipped
  * Fixed guild rank not showing in dialogue
  * Fixed flash of blue when sneaking and opening a container or the inventory
  * Fixed incorrect level-up class image when using a custom class
  * Fixed mis-aligned buttons on quit menu
  * Fixed an NPC stuck hovering in a jumping animation
  * Fixed crash when loading the Big City esm file.
  * Fixed mis-aligned dialogue topic list when scrolling
  * Fixed certain faction memberships not storing in saved games
  * Fixed pasting text always inserting at the end of a text box, instead of at the cursor
  * Fixed conversation loop when asking about "specific place" in Vivec
  * Fixed Caius not leaving at the start of the "Mehra Milo and the Lost Prophecies" quest
  * Fixed map markers not being saved in save games
  * Fixed "ring_keley" causing exception
  * Fixed open dialogues not being closed when loading a game
  * Fixed some collision geometry cleanup
  * Fixed a special case script instruction for the Athyn Sarethi mission
  * Fixed an improper handling of a special NIF format case that caused problems with the Pluginless Khajiit Head Pack
  * OpenCS: Implemented region map context menu
  * OpenCS: Implemented region map drag & drop
  * OpenCS: Implemented scene subview drop
  * OpenCS: Implemented preview subview
  * OpenCS: Implemented OGRE integration
  * OpenCS: Implemented Dialogue Sub-Views
  * OpenCS: Implemented lighting modes
  * OpenCS: Implemented different camera navigation modes
  * OpenCS: Refactored user settings
  * OpenCS: Fixed failure when dropping a region into the filter of a cell subview
  * OpenCS: Fixed exception when loading files
  Known Issues:
  * Character generation can be skipped
  * Some items can be stolen without raising an alarm
  * Sound may be disabled on videos in Windows
* Mon Apr  8 2013 devel.suse@gmail.com
- Update to upstream version 0.22.0:
  * Implemented Active Spell Icons
  * Implemented walking, running, and swimming animation
  * Implemented support for ESPs and multiple ESMs
  * Implemented proper collision shapes for NPCs and creatures
  * Implemented lights that behave more like vanilla Morrowind
  * Implemented importing BSA files as part of the settings imported by the config importer
  * Implemented zoom in vanity mode
  * Implemented potion/ingredient effect stacking
  * Implemented object movement between cells
  * Implemented closing message boxes by pressing the activation key
  * Implemented random persuasion responses
  * Implemented closing message boxes when enter is pressed
  * Use rendered object shape for physics raycasts
  * Improved the race selection preview camera
  * Class and Birthsign menus options are now preselected
  * Disabled dialog window until character creation is finished
  * Decoupled water animation speed from timescale
  * Changed underwater rendering to more closely resemble vanilla Morrowind
  * Hid potion effects until discovered
  * Finished class selection-dialogue
  * Re-factored Launcher ESX selector into a re-usable component
  * Various fixes and implementations for the script compiler
  * Fix for a keyboard repeat rate issue
  * Fix for errant character outline on water in 3rd person
  * Fix for duplicate player collision model at origin
  * Fix for dialogue list jumping when a topic is clicked
  * Fix to prevent attributes/skills going below zero
  * Fix for global variables of type short being read incorrectly
  * Fix for collision and tooltip on invisible meshes
  * Fix for CG showing in Options when it is not available
  * Fix for crash when Alt-tabbing with the console open
  * Fix for pick up sound playing when object cannot be picked up
  * Fix for moving left or right canceling auto-move
  * Fix for gender being swapped (woops!)
  * Fix for footless guards
  * Fix for waterfalls not rendering at a certain distance
  * Fix for crash in “Mournhold, Royal Palace”
  * Fix for not finding non-DDS textures
  * Fix for some meshes being invisible from above water in Bloodmoon
  * Fix for Messagebox causing assert to fail
  * Fixes for Launcher file path selection
  * Fixes for missing/incorrect UI graphical elements
  * Fixes for various transparency rendering issues
  * Fixes fo various character generation UI issues
  * Fixes for config import in Launcher
  * Fixes for various new issues discovered when handling mod content
  * Various code cleanup
* Thu Feb 21 2013 devel.suse@gmail.com
- Update to upstream version 0.21.0:
  * Various dialogue, trading, and disposition fixes and improvements
  * Torch flickering improved to better match vanilla Morrowind
  * Fix for attribute fluctuation when infected with Ash Woe Blight
  * Adjusted activation range to better match vanilla Morrowind
  * Fixes for the Journal UI
  * Fixed crash caused by Golden Saint models
  * Fix for beast races being able to wear shoes
  * Fix for background music not playing
  * Fix for meshes without certain node names not being loaded
  * Fix for incorrect terrain shape on inital cell load
  * Fix for MWGui::InventoryWindow creating a duplicate player actor at the origin
  * Added video playback
  * Added support for escape sequences in message box and dialogue text
  * Added AI related script functions, note that AI is not functional yet
  * Implemented fallbacks for necessary ini values in the importer, unused in OpenMW as of yet
  * Implemented execution of scripts of objects in containers/inventories in active cells
  * Cell loading performance improvements
  * Removed broken GMST contamination fixing mechanism
  Known Issues:
  * No sound when playing videos on OS X
  * Extreme shaking may occur during cell transitions for some users (enable anti-aliasing as a possible workaround)
  * Launcher crash on OS X < 10.8
* Wed Feb 13 2013 devel.suse@gmail.com
- Update to upstream version 0.20.0:
  * Implemented all missing dialogue filters
  * Implemented Mercantile skill
  * Implemented Persuasion dialogue
  * Initial implementation of AI package classes
  * Implemented 2nd layer for Global map
  * Implemented Animation pausing while game is paused
  * Implemented Player race now changes visually during character creation
  * Fixed Cell reloading when using teleport doors that link to the same cell
  * Fixed “0 a.m.” to display as “12 a.m.”
  * Fixed text persisting in the “name” field of the potion/spell creation window
  * Fixed starting date of new games
  * Fixed console window close behavior
  * Fixed container window formatting to better accommodate long item names
  * Fixed some topics not automatically being added to the known topic list
  * Fixed auto-move working despite DisablePlayerControls being set
  * Fixed rest dialogue opening again after resting
  * Fixed double removal of ingredients when creating potions
  * Various engine code and scripting improvements
  Known Issues:
  * Extreme shaking may occur during cell transitions for some users (enable anti-aliasing as a possible workaround)
  * The disposition implementation is severely broken and will give wrong numbers in many cases
  * Entering a cell containing a Golden Saint model will crash the game
  * A journal regression causes journal updates to not display correctly
* Sun Oct 14 2012 devel.suse@gmail.com
- Update to upstream version 0.18.0:
  * Implemented Level-Up dialog
  * Implemented Hide Marker, fixes big black blocks
  * Implemented Hotkey dialog
  * Implemented Keyboard and Mouse bindings, input system rewritten
  * Implemented Spell Buying Window
  * Added support for handling resources across multiple data directories
  * Implemented Object Movement/Creation script instructions
  * Initial AI framework implemented
  * Implemented eating Ingredients
  * Implemented Door markers on the local map
  * Implemented using Keys to open doors/containers
  * Implemented Loading screens
  * Implemented Inventory avatar image and race selection head preview (note that only default Dunmer male displays at the moment)
  * Fixed the size of Preferences menu buttons
  * Fixed Hand-to-hand always being 100
  * Fixes for NPC and character animation
  * Fix for sound coordinates
  * Fix for exception when drinking self-made potions
  * Fix for clothes showing up in 1st person
  * Fix for weird character on door tooltips
  * Collision fixes
  * Fix for “onOfferButtonClicked” crash
  Known Issues:
  * The launcher can crash on OS X versions < 10.8, this will be fixed in version 0.19.0
  * “Shaking screen effect” can occur on cell change
* Sun Sep 23 2012 devel.suse@gmail.com
- added .rpmlintrc file to skip "devel-files-in-no-devel-package"
- now game should be run from wrappers: openmw.sh and omwlauncher.sh
* Tue Sep 18 2012 devel.suse@gmail.com
- Update to upstream version 0.17.0:
  * Fixes for physics shapes and dark textures
  * Fix for character normals
  * Fix for laggy input on OS X
  * Added support for objects crossing cell borders
  * Re-implemented dropping items
  * Implemented a Main Menu
  * Implemented Camera Modes and proper Player control
  * Added support for object rotation and scaling
  * Fix for NIF material sharing
  * Implemented potion usage
  * Implemented skill gain backend
  * Implemented Drain/Fortigy dynamic Stats/Attributes magic effects
  * Fix for various crashes and errors
  * Fixes for memory leaks
  * Various improvements for console scripts
  * Various code cleanup and improvements
  Known Issues:
  * Activating a bed can lock up the game
  * There is a minor memory leak that will be fixed in 0.18.0
* Sun Jul  1 2012 devel.suse@gmail.com
- Initial package creation
